# PASSED: Test Report

Description:

Tester | tao.xu
Start | 2020-11-17 10:55:34
End | 2020-11-17 10:55:34
Elapsed | 0:00:00
Summary | ALL 1, Pass 1, Passing rate: 100%
Location | LAPTOP-9M6BOS48(10.116.0.33)
Report | C:\workspace\stress-runner\test\report.html
Command | python C:/workspace/stress-runner/test/test.py

Nodes:

NodeName | STATUS | IP | Roles | User | Password
LAPTOP-9M6BOS48 | Ready | 10.116.0.33 | Test Host | root | password

Summary:

Total | Pass | Fail | Error | Skip | Cancel | Passing Rate
1 | 1 | 0 | 0 | 0 | 0 | 100%

Details:

Test Group/Case | Status | Elapsed Time | Iteration
test_1 | PASS | 0:00:00 | Loop: 1